@@ -345,11 +345,21 @@ CLICommands = [
                 "cmdClass": "PrintSampleTestConfigurationCLI"
             },      
             {
-                "name": ["run-test-object"],
+                "name": ["verify-device-group-consistency"],
+                "cmdFile": "%s/../d2c/test/verify_device_group_consistency.py" % (os.path.dirname(__file__)),
+                "cmdClass": "VerifyDeviceGroupConsistencyCLI"
+            },                   
+            {
+                "name": ["get-resource-performance-test"],
+                "cmdFile": "%s/../d2c/test/perftest_get_resource.py" % (os.path.dirname(__file__)),
+                "cmdClass": "PerformanceTest_GetResourceCLI"
+            },          
+            {
+                "name": ["run-test-cases"],
                 "cmdFile": "%s/../d2c/test/all_test_cases_runner.py" % (os.path.dirname(__file__)),
                 "cmdClass": "AllTestCasesRunner_CLI"
             },    
-
+            
             #########################
             # Application test cases              
             {
@@ -593,62 +603,6 @@ CLICommands = [
                 "cmdFile": "%s/../d2c/test/test_cases_device_group.py" % (os.path.dirname(__file__)),
                 "cmdClass": "DeviceGroupTest_DG21_CLI"
             },                  
-            # {
-            #     "name": ["test-dg06"],
-            #     "cmdFile": "%s/../d2c/test/test_cases_device_group.py" % (os.path.dirname(__file__)),
-            #     "cmdClass": "DeviceGroupTest_DG06_CLI"
-            # },                  
-            ########################
-            {
-                "name": ["test-application-00"],
-                "cmdFile": "%s/../d2c/test/application.py" % (os.path.dirname(__file__)),
-                "cmdClass": "FunctionalTest_Application00CLI"
-            },    
-            {
-                "name": ["test-application-01"],
-                "cmdFile": "%s/../d2c/test/application.py" % (os.path.dirname(__file__)),
-                "cmdClass": "FunctionalTest_Application01CLI"
-            },    
-            {
-                "name": ["test-device-00"],
-                "cmdFile": "%s/../d2c/test/device.py" % (os.path.dirname(__file__)),
-                "cmdClass": "Tests00_CLI"
-            },                             
-            {
-                "name": ["test-device-01"],
-                "cmdFile": "%s/../d2c/test/device.py" % (os.path.dirname(__file__)),
-                "cmdClass": "Tests01_CLI"
-            },                             
-            {
-                "name": ["test-device-group-01"],
-                "cmdFile": "%s/../d2c/test/device_group.py" % (os.path.dirname(__file__)),
-                "cmdClass": "Tests01_CLI"
-            },                
-            {
-                "name": ["test-device-group-02"],
-                "cmdFile": "%s/../d2c/test/device_group.py" % (os.path.dirname(__file__)),
-                "cmdClass": "Tests02_CLI"
-            },                
-            {
-                "name": ["device-group-test-03"],
-                "cmdFile": "%s/../d2c/test/device_group.py" % (os.path.dirname(__file__)),
-                "cmdClass": "Tests03_CLI"
-            },                   
-            {
-                "name": ["test-device-group-04"],
-                "cmdFile": "%s/../d2c/test/device_group.py" % (os.path.dirname(__file__)),
-                "cmdClass": "Tests04_CLI"
-            },                   
-            {
-                "name": ["verify-device-group-consistency"],
-                "cmdFile": "%s/../d2c/test/verify_device_group_consistency.py" % (os.path.dirname(__file__)),
-                "cmdClass": "VerifyDeviceGroupConsistencyCLI"
-            },                   
-            {
-                "name": ["get-resource-performance-test"],
-                "cmdFile": "%s/../d2c/test/perftest_get_resource.py" % (os.path.dirname(__file__)),
-                "cmdClass": "PerformanceTest_GetResourceCLI"
-            },          
         ]
     },    
 ]
