@@ -491,85 +491,3 @@ class TestCase_InjectUplinkMessage(TestCase):
             
             tutils.exec_test(f"Getting injected message {message_name}", operation)    
             
-###########################################################################            
-# Performs the following test cases:
-# - create device
-###########################################################################            
-class Tests00(TestSet):
-    def __init__(self, api: ApiClient):
-        super().__init__(api, "Device Tests 00")
-    
-    def get_sample_configuration_varname(self)->str:
-        return "Device01Cfg"
-
-    def get_test_cases(self, cfg:dict)->List[TestCase]:
-        return [
-            TestCase_CreateDevice(api=self.api, cfg=cfg),
-        ]
-    
-    def test_pre_cleanup(self, cfg:dict)->str:
-        name = cfg.get("name")
-        def operation():
-            if (device := Device.get(self.api, name=name)):
-                Device.delete(self.api, name=name)
-            return None
-        return tutils.exec_test(f"Deleting device {name}", operation)
-    
-    def test_post_cleanup(self, cfg:dict)->str:
-        name = cfg.get("name")
-        def operation():
-            if (device := Device.get(self.api, name=name)):
-                Device.delete(self.api, name=name)
-            return None
-        return tutils.exec_test(f"Deleting device {name}", operation)
-
-class Tests00_CLI(TestCLI_Base):
-    def get1LineHelp(self):
-        return "Runs the device test case 00: create device."
-    
-    def get_test_set(self, api: ApiClient):
-        return Tests00(api)
-
-###########################################################################            
-# Performs the following test cases:
-# - create device
-# - modify device
-# - delete device
-###########################################################################    
-class Tests01(TestSet):
-    def __init__(self, api: ApiClient):
-        super().__init__(api, "Device Tests 01")
-    
-    def get_sample_configuration_varname(self)->str:
-        return "Device01Cfg"
-
-    def get_test_cases(self, cfg:dict)->List[TestCase]:
-        return [
-            TestCase_CreateDevice(api=self.api, cfg=cfg),
-            TestCase_ModifyDevice(api=self.api, cfg=cfg),
-            TestCase_DeleteDevice(api=self.api, cfg=cfg)
-        ]
-    
-    def test_pre_cleanup(self, cfg:dict)->str:
-        name = cfg.get("name")
-        def operation():
-            if (device := Device.get(self.api, name=name)):
-                Device.delete(self.api, name=name)
-            return None
-        return tutils.exec_test(f"Deleting device {name}", operation)
-    
-    def test_post_cleanup(self, cfg:dict)->str:
-        name = cfg.get("name")
-        def operation():
-            if (device := Device.get(self.api, name=name)):
-                Device.delete(self.api, name=name)
-            return None
-        return tutils.exec_test(f"Deleting device {name}", operation)
-
-class Tests01_CLI(TestCLI_Base):
-    def get1LineHelp(self):
-        return "Runs the device test case 01: create, modify, delete device."
-    
-    def get_test_set(self, api: ApiClient):
-        return Tests01(api)
-    
\ No newline at end of file
