@@ -745,208 +745,3 @@ class TestCase_InjectUplinkMessage(TestCase):
                 
             tutils.exec_test(f"Getting message from {url} and testing correlation id {correlation_id}", operation)
         
-#MARK: Tests01
-###########################################################################            
-# Performs the following test cases:
-# - create device group
-# - modify device group
-# - delete device group
-###########################################################################    
-class Tests01(TestSet):
-    def __init__(self, api: ApiClient):
-        super().__init__(api, "TestGroup Tests 01")
-    
-    def get_sample_configuration_varname(self)->str:
-        return "DeviceGroup01Cfg"
-
-    def get_test_cases(self, cfg:dict)->List[TestCase]:
-        return [
-            TestCase_CreateDeviceGroup(api=self.api, cfg=cfg),
-            TestCase_ModifyDeviceGroup(api=self.api, cfg=cfg),
-            TestCase_DeleteDeviceGroup(api=self.api, cfg=cfg),
-        ]
-        
-    def test_pre_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-
-    def test_post_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-
-class Tests01_CLI(TestCLI_Base):
-    def get1LineHelp(self):
-        return "Runs device group test case: create, modify and delete device group."
-    def get_test_set(self, api: ApiClient):
-        return Tests01(api)
-#MARK: Tests02
-###########################################################################            
-# Performs the following test cases:
-# - create device group
-# - create application
-# - create application
-# - remove application
-# - add 2 applications 
-# - remove application
-# - remove application
-###########################################################################    
-class Tests02(TestSet):
-    def __init__(self, api: ApiClient):
-        super().__init__(api, "TestGroup Tests 02")
-    
-    def get_sample_configuration_varname(self)->str:
-        return "DeviceGroup02Cfg"
-
-    def get_test_cases(self, cfg:dict)->List[TestCase]:
-        return [
-            TestCase_CreateDeviceGroup(api=self.api, cfg=cfg),
-            TestCase_CreateApplication(api=self.api, cfg=cfg.get("application_1")),
-            TestCase_CreateApplication(api=self.api, cfg=cfg.get("application_2")),
-            TestCase_AddApplicationsToDeviceGroup(api=self.api, 
-                                                  device_group_cfg=cfg, 
-                                                  application_cfgs=[cfg.get("application_1")]),
-            TestCase_RemoveApplicationsFromDeviceGroup(api=self.api, 
-                                                      device_group_cfg=cfg, 
-                                                      application_cfgs=[cfg.get("application_1")]),
-            TestCase_AddApplicationsToDeviceGroup(api=self.api, 
-                                                  device_group_cfg=cfg, 
-                                                  application_cfgs=[cfg.get("application_1"), 
-                                                                    cfg.get("application_2")]),
-            TestCase_RemoveApplicationsFromDeviceGroup(api=self.api, 
-                                                      device_group_cfg=cfg, 
-                                                      application_cfgs=[cfg.get("application_1")]),
-            TestCase_RemoveApplicationsFromDeviceGroup(api=self.api, 
-                                                      device_group_cfg=cfg, 
-                                                      application_cfgs=[cfg.get("application_2")]),
-        ]
-        
-    def test_pre_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-        delete_application(self.api, cfg.get("application_1").get("name"))
-        delete_application(self.api, cfg.get("application_2").get("name"))
-
-    def test_post_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-        delete_application(self.api, cfg.get("application_1").get("name"))
-        delete_application(self.api, cfg.get("application_2").get("name"))
-
-class Tests02_CLI(TestCLI_Base):
-    def get1LineHelp(self):
-        return "Runs device group test case: add applications, remove applications without devices."
-
-    def get_test_set(self, api: ApiClient):
-        return Tests02(api)
-#MARK: Tests03
-###########################################################################            
-# Performs the following test cases:
-# - create device group
-# - create device
-# - create device
-# - add device to device group
-# - remove device group
-# - add 2 devices to device group
-# - remove device group
-# - remove device group
-###########################################################################    
-class Tests03(TestSet):
-    def __init__(self, api: ApiClient):
-        super().__init__(api, "TestGroup Tests 03")
-    
-    def get_sample_configuration_varname(self)->str:
-        return "DeviceGroup02Cfg"
-
-    def get_test_cases(self, cfg:dict)->List[TestCase]:
-        return [
-            TestCase_CreateDeviceGroup(api=self.api, cfg=cfg),
-            
-            TestCase_CreateDevice(api=self.api, cfg=cfg.get("device_1")),
-            TestCase_CreateDevice(api=self.api, cfg=cfg.get("device_2")),
-            TestCase_AddDevicesToDeviceGroup(api=self.api, 
-                                            device_group_cfg=cfg, 
-                                            device_cfgs=[cfg.get("device_1")],
-                                            verify_application_cfgs=None),
-            TestCase_RemoveDevicesFromDeviceGroup(api=self.api, 
-                                                  device_group_cfg=cfg, 
-                                                  device_cfgs=[cfg.get("device_1")]),
-            TestCase_AddDevicesToDeviceGroup(api=self.api, 
-                                            device_group_cfg=cfg, 
-                                            device_cfgs=[cfg.get("device_1"), cfg.get("device_2")],
-                                            verify_application_cfgs=None),
-            TestCase_RemoveDevicesFromDeviceGroup(api=self.api, 
-                                                  device_group_cfg=cfg, 
-                                                  device_cfgs=[cfg.get("device_1"), cfg.get("device_2")])
-        ]
-        
-    def test_pre_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-        delete_device(self.api, cfg.get("device_1").get("name"))
-        delete_device(self.api, cfg.get("device_2").get("name"))
-
-    def test_post_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-        delete_device(self.api, cfg.get("device_1").get("name"))
-        delete_device(self.api, cfg.get("device_2").get("name"))
-class Tests03_CLI(TestCLI_Base):
-    def get1LineHelp(self):
-        return "Runs device group test case: add devices, remove devices without applications."
-
-    def get_test_set(self, api: ApiClient):
-        return Tests03(api)
-#MARK: Tests04
-###########################################################################            
-# Performs the following test cases:
-# - create device group
-# - create application 
-# - create device
-# - add applications to device group
-# - add device to device group
-# - remove device from device group
-# - add device to device group
-# - remove application from device group 
-###########################################################################    
-class Tests04(TestSet):
-    def __init__(self, api: ApiClient):
-        super().__init__(api, "TestGroup Tests 04")
-    
-    def get_sample_configuration_varname(self)->str:
-        return "DeviceGroup02Cfg"
-
-    def get_test_cases(self, cfg:dict)->List[TestCase]:
-        return [
-            TestCase_CreateDeviceGroup(api=self.api, cfg=cfg),
-            TestCase_CreateApplication(api=self.api, cfg=cfg.get("application_1")),
-            TestCase_CreateApplication(api=self.api, cfg=cfg.get("application_2")),
-            TestCase_CreateDevice(api=self.api, cfg=cfg.get("device_1")),
-            TestCase_CreateDevice(api=self.api, cfg=cfg.get("device_2")),
-            TestCase_AddApplicationsToDeviceGroup(api=self.api, 
-                                                  device_group_cfg=cfg, 
-                                                  application_cfgs=[cfg.get("application_1"), cfg.get("application_2")],
-                                                  verify_device_cfgs=None),
-            TestCase_AddDevicesToDeviceGroup(api=self.api, 
-                                            device_group_cfg=cfg, 
-                                            device_cfgs=[cfg.get("device_1"), cfg.get("device_2")],
-                                            verify_application_cfgs=[cfg.get("application_1"), cfg.get("application_2")]),
-            TestCase_RemoveDevicesFromDeviceGroup(api=self.api, 
-                                                  device_group_cfg=cfg, 
-                                                  device_cfgs=[cfg.get("device_1")],
-                                                  verify_application_cfgs=[cfg.get("application_1")]),
-            TestCase_RemoveApplicationsFromDeviceGroup(api=self.api, 
-                                                      device_group_cfg=cfg, 
-                                                      application_cfgs=[cfg.get("application_1")],
-                                                      verify_device_cfgs=[cfg.get("device_1")]),
-        ]
-        
-    def test_pre_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-        delete_application(self.api, cfg.get("application_1").get("name"))
-        delete_device(self.api, cfg.get("device_1").get("name"))
-
-    def test_post_cleanup(self, cfg:dict)->str:
-        delete_device_group(self.api, cfg.get("name"))
-        delete_application(self.api, cfg.get("application_1").get("name"))
-        delete_device(self.api, cfg.get("device_1").get("name"))
-
-class Tests04_CLI(TestCLI_Base):
-    def get1LineHelp(self):
-        return "Runs device group test case: add and remove application and device."
-
-    def get_test_set(self, api: ApiClient):
-        return Tests04(api)    
